#!/sbin/sh
#---------------------------------------------
# Yank555.lu - Kernel options script generator
#---------------------------------------------

script_path="/tmp/Yank555.lu/script"
script_name="init.yank555.lu.kernel.sh"
log_file="/data/kernel-script.log"
sub_scripts_path="$script_path/sub-scripts"
props_path="/tmp/aroma"

# Start making the script header -----------------------------------------------------------------

rm $log_file

echo "----------------------------------------------------" >>$log_file
echo "Kernel options init.d script generator by Yank555.lu" >>$log_file
echo "----------------------------------------------------" >>$log_file
date "+Script generated on %d/%m/%Y at %k:%M" >>$log_file
echo "----------------------------------------------------" >>$log_file
echo "" >>$log_file
echo "Preparing init.d script header" >>$log_file

rm $script_path/$script_name >>$log_file
cp $sub_scripts_path/header $script_path/$script_name >>$log_file
date "+# Script generated on %d/%m/%Y at %k:%M" >>$script_path/$script_name
echo "#----------------------------------------------------" >>$script_path/$script_name
echo "" >>$script_path/$script_name

# Add SELinux configuration ----------------------------------------------------------------------

if [ "`grep selected.1= $props_path/SELinux.prop | awk -F= '{print $2;}'`" != "" ]
  then
    echo "     SELinux = `grep selected.1= $props_path/SELinux.prop | awk -F= '{print $2;}'`" >>$log_file
    cat $sub_scripts_path/SELinux/1.`grep selected.1= $props_path/SELinux.prop | awk -F= '{print $2;}'` >>$script_path/$script_name
fi;

# Add init.d configuration -----------------------------------------------------------------------

echo "" >>$log_file
echo "init.d support configuration" >>$log_file

if [ "`grep selected.1= $props_path/initd.prop | awk -F= '{print $2;}'`" != "" ]
  then
    echo "     init.d support = `grep selected.1= $props_path/initd.prop | awk -F= '{print $2;}'`" >>$log_file
    cat $sub_scripts_path/initd/1.`grep selected.1= $props_path/initd.prop | awk -F= '{print $2;}'` >>$script_path/$script_name
    if [ ! -e /system/etc/init.d ] ; then
        mkdir /system/etc/init.d
        chgrp 2000 /system/etc/init.d
        chmod 755 /system/etc/init.d
        echo "     (init.d folder created)" >>$log_file
    fi
fi;

# GPU configuration ------------------------------------------------------------------------------

echo "" >>$log_file
echo "GPU configuration" >>$log_file

if [ "`grep selected.1= $props_path/gpu.prop | awk -F= '{print $2;}'`" != "" ]
  then
    echo "     Simple GPU governor      = `grep selected.1= $props_path/gpu.prop | awk -F= '{print $2;}'`" >>$log_file
    cat $sub_scripts_path/gpu/1.`grep selected.1= $props_path/gpu.prop | awk -F= '{print $2;}'` >>$script_path/$script_name
fi;

if [ "`grep selected.2= $props_path/gpu.prop | awk -F= '{print $2;}'`" != "" ]
  then
    echo "     Simple GPU algorithm     = `grep selected.2= $props_path/gpu.prop | awk -F= '{print $2;}'`" >>$log_file
    cat $sub_scripts_path/gpu/2.`grep selected.2= $props_path/gpu.prop | awk -F= '{print $2;}'` >>$script_path/$script_name
fi;

if [ "`grep selected.3= $props_path/gpu.prop | awk -F= '{print $2;}'`" != "" ]
  then
    echo "     Simple GPU laziness      = `grep selected.3= $props_path/gpu.prop | awk -F= '{print $2;}'`" >>$log_file
    cat $sub_scripts_path/gpu/3.`grep selected.3= $props_path/gpu.prop | awk -F= '{print $2;}'` >>$script_path/$script_name
fi;

if [ "`grep selected.4= $props_path/gpu.prop | awk -F= '{print $2;}'`" != "" ]
  then
    echo "     Simple GPU ramp down     = `grep selected.4= $props_path/gpu.prop | awk -F= '{print $2;}'`" >>$log_file
    cat $sub_scripts_path/gpu/4.`grep selected.4= $props_path/gpu.prop | awk -F= '{print $2;}'` >>$script_path/$script_name
fi;

# CPU configuration ------------------------------------------------------------------------------

echo "" >>$log_file
echo "CPU configuration" >>$log_file

#if [ "`grep selected.12= $props_path/cpu.prop | awk -F= '{print $2;}'`" != "" ]
#  then
#    echo "     Userspace DVFS lock      = `grep selected.12= $props_path/cpu.prop | awk -F= '{print $2;}'`" >>$log_file
#    cat $sub_scripts_path/cpu/12.`grep selected.12= $props_path/cpu.prop | awk -F= '{print $2;}'` >>$script_path/$script_name
#fi;

if [ "`grep selected.1= $props_path/cpu.prop | awk -F= '{print $2;}'`" != "" ]
  then
    echo "     CPU Governor             = `grep selected.1= $props_path/cpu.prop | awk -F= '{print $2;}'`" >>$log_file
    cat $sub_scripts_path/cpu/1.`grep selected.1= $props_path/cpu.prop | awk -F= '{print $2;}'` >>$script_path/$script_name
fi;

#if [ "`grep selected.2= $props_path/cpu.prop | awk -F= '{print $2;}'`" != "" ]
#  then
#    echo "     CPU min screen on        = `grep selected.2= $props_path/cpu.prop | awk -F= '{print $2;}'`" >>$log_file
#    cat $sub_scripts_path/cpu/2.`grep selected.2= $props_path/cpu.prop | awk -F= '{print $2;}'` >>$script_path/$script_name
#fi;
#
#if [ "`grep selected.3= $props_path/cpu.prop | awk -F= '{print $2;}'`" != "" ]
#  then
#    echo "     CPU min screen off       = `grep selected.3= $props_path/cpu.prop | awk -F= '{print $2;}'`" >>$log_file
#    cat $sub_scripts_path/cpu/3.`grep selected.3= $props_path/cpu.prop | awk -F= '{print $2;}'` >>$script_path/$script_name
#fi;
#
#if [ "`grep selected.4= $props_path/cpu.prop | awk -F= '{print $2;}'`" != "" ]
#  then
#    echo "     CPU max screen on        = `grep selected.4= $props_path/cpu.prop | awk -F= '{print $2;}'`" >>$log_file
#    cat $sub_scripts_path/cpu/4.`grep selected.4= $props_path/cpu.prop | awk -F= '{print $2;}'` >>$script_path/$script_name
#fi;
#
#if [ "`grep selected.5= $props_path/cpu.prop | awk -F= '{print $2;}'`" != "" ]
#  then
#    echo "     CPU max screen off       = `grep selected.5= $props_path/cpu.prop | awk -F= '{print $2;}'`" >>$log_file
#    cat $sub_scripts_path/cpu/5.`grep selected.5= $props_path/cpu.prop | awk -F= '{print $2;}'` >>$script_path/$script_name
#fi;
#
#if [ "`grep selected.6= $props_path/cpu.prop | awk -F= '{print $2;}'`" != "" ]
#  then
#    echo "     CPU wakeup kick freq     = `grep selected.6= $props_path/cpu.prop | awk -F= '{print $2;}'`" >>$log_file
#    cat $sub_scripts_path/cpu/6.`grep selected.6= $props_path/cpu.prop | awk -F= '{print $2;}'` >>$script_path/$script_name
#fi;
#
#if [ "`grep selected.7= $props_path/cpu.prop | awk -F= '{print $2;}'`" != "" ]
#  then
#    echo "     CPU wakeup kick delay    = `grep selected.7= $props_path/cpu.prop | awk -F= '{print $2;}'`" >>$log_file
#    cat $sub_scripts_path/cpu/7.`grep selected.7= $props_path/cpu.prop | awk -F= '{print $2;}'` >>$script_path/$script_name
#fi;
#
#if [ "`grep selected.8= $props_path/cpu.prop | awk -F= '{print $2;}'`" != "" ]
#  then
#    echo "     CPU touchboost delay     = `grep selected.8= $props_path/cpu.prop | awk -F= '{print $2;}'`" >>$log_file
#    cat $sub_scripts_path/cpu/8.`grep selected.8= $props_path/cpu.prop | awk -F= '{print $2;}'` >>$script_path/$script_name
#fi;
#
#if [ "`grep selected.9= $props_path/cpu.prop | awk -F= '{print $2;}'`" != "" ]
#  then
#    echo "     CPU touchboost hi events = `grep selected.9= $props_path/cpu.prop | awk -F= '{print $2;}'`" >>$log_file
#    cat $sub_scripts_path/cpu/9.`grep selected.9= $props_path/cpu.prop | awk -F= '{print $2;}'` >>$script_path/$script_name
#fi;
#
#if [ "`grep selected.10= $props_path/cpu.prop | awk -F= '{print $2;}'`" != "" ]
#  then
#    echo "     CPU touchboost lo freq   = `grep selected.10= $props_path/cpu.prop | awk -F= '{print $2;}'`" >>$log_file
#    cat $sub_scripts_path/cpu/10.`grep selected.10= $props_path/cpu.prop | awk -F= '{print $2;}'` >>$script_path/$script_name
#fi;
#
#if [ "`grep selected.11= $props_path/cpu.prop | awk -F= '{print $2;}'`" != "" ]
#  then
#    echo "     CPU touchboost hi freq   = `grep selected.11= $props_path/cpu.prop | awk -F= '{print $2;}'`" >>$log_file
#    cat $sub_scripts_path/cpu/11.`grep selected.11= $props_path/cpu.prop | awk -F= '{print $2;}'` >>$script_path/$script_name
#fi;

# Hotplug configuration ------------------------------------------------------------------------------

echo "" >>$log_file
echo "Hotplug configuration" >>$log_file

if [ "`grep selected.1= $props_path/hotplug.prop | awk -F= '{print $2;}'`" != "" ]
  then
    echo "     Hotplug Driver         = `grep selected.1= $props_path/hotplug.prop | awk -F= '{print $2;}'`" >>$log_file
    cat $sub_scripts_path/hotplug/1.`grep selected.1= $props_path/hotplug.prop | awk -F= '{print $2;}'` >>$script_path/$script_name
fi;

if [ "`grep selected.2= $props_path/hotplug.prop | awk -F= '{print $2;}'`" != "" ]
  then
    echo "     IntelliPlug Profile    = `grep selected.2= $props_path/hotplug.prop | awk -F= '{print $2;}'`" >>$log_file
    cat $sub_scripts_path/hotplug/2.`grep selected.2= $props_path/hotplug.prop | awk -F= '{print $2;}'` >>$script_path/$script_name
fi;

if [ "`grep selected.3= $props_path/hotplug.prop | awk -F= '{print $2;}'`" != "" ]
  then
    echo "     IntelliPlug Hysteresis = `grep selected.3= $props_path/hotplug.prop | awk -F= '{print $2;}'`" >>$log_file
    cat $sub_scripts_path/hotplug/3.`grep selected.3= $props_path/hotplug.prop | awk -F= '{print $2;}'` >>$script_path/$script_name
fi;

if [ "`grep selected.4= $props_path/hotplug.prop | awk -F= '{print $2;}'`" != "" ]
  then
    echo "     IntelliPlug Runqueue   = `grep selected.4= $props_path/hotplug.prop | awk -F= '{print $2;}'`" >>$log_file
    cat $sub_scripts_path/hotplug/4.`grep selected.4= $props_path/hotplug.prop | awk -F= '{print $2;}'` >>$script_path/$script_name
fi;

# Thermal configuration ------------------------------------------------------------------------------

echo "" >>$log_file
echo "Thermal configuration" >>$log_file

if [ "`grep selected.1= $props_path/thermal.prop | awk -F= '{print $2;}'`" != "" ]
  then
    echo "     Thermal Driver       = `grep selected.1= $props_path/thermal.prop | awk -F= '{print $2;}'`" >>$log_file
    cat $sub_scripts_path/thermal/1.`grep selected.1= $props_path/thermal.prop | awk -F= '{print $2;}'` >>$script_path/$script_name
fi;

if [ "`grep selected.2= $props_path/thermal.prop | awk -F= '{print $2;}'`" != "" ]
  then
    echo "     IntelliThermal Freq. = `grep selected.2= $props_path/thermal.prop | awk -F= '{print $2;}'`" >>$log_file
    cat $sub_scripts_path/thermal/2.`grep selected.2= $props_path/thermal.prop | awk -F= '{print $2;}'` >>$script_path/$script_name
fi;

if [ "`grep selected.3= $props_path/thermal.prop | awk -F= '{print $2;}'`" != "" ]
  then
    echo "     IntelliThermal Core. = `grep selected.3= $props_path/thermal.prop | awk -F= '{print $2;}'`" >>$log_file
    cat $sub_scripts_path/thermal/3.`grep selected.3= $props_path/thermal.prop | awk -F= '{print $2;}'` >>$script_path/$script_name
fi;

# Vibrator strength configuration ----------------------------------------------------------------

echo "" >>$log_file
echo "Vibrator strength configuration" >>$log_file

if [ "`grep selected.1= $props_path/vibrator.prop | awk -F= '{print $2;}'`" != "" ]
  then
    echo "     Strength = `grep selected.1= $props_path/vibrator.prop | awk -F= '{print $2;}'`" >>$log_file
    cat $sub_scripts_path/vibrator/1.`grep selected.1= $props_path/vibrator.prop | awk -F= '{print $2;}'` >>$script_path/$script_name
fi;

# LED configuration ------------------------------------------------------------------------------

echo "" >>$log_file
echo "LED configuration" >>$log_file

if [ "`grep selected.1= $props_path/LED.prop | awk -F= '{print $2;}'`" != "" ]
  then
    echo "     Charging LED = `grep selected.1= $props_path/LED.prop | awk -F= '{print $2;}'`" >>$log_file
    cat $sub_scripts_path/LED/1.`grep selected.1= $props_path/LED.prop | awk -F= '{print $2;}'` >>$script_path/$script_name
fi;

# dt2w configuration -----------------------------------------------------------------------------

echo "" >>$log_file
echo "Double-tap to wake configuration" >>$log_file

if [ "`grep selected.1= $props_path/dt2w.prop | awk -F= '{print $2;}'`" != "" ]
  then
    echo "     dt2w = `grep selected.1= $props_path/dt2w.prop | awk -F= '{print $2;}'`" >>$log_file
    cat $sub_scripts_path/dt2w/1.`grep selected.1= $props_path/dt2w.prop | awk -F= '{print $2;}'` >>$script_path/$script_name
fi;

# Add MMC I/O configuration ----------------------------------------------------------------------

echo "" >>$log_file
echo "MMC I/O configuration" >>$log_file

if [ "`grep selected.1= $props_path/io.prop | awk -F= '{print $2;}'`" != "" ]
  then
    echo "     Internal ReadAhead size  = `grep selected.1= $props_path/io.prop | awk -F= '{print $2;}'`" >>$log_file
    cat $sub_scripts_path/io/1.`grep selected.1= $props_path/io.prop | awk -F= '{print $2;}'` >>$script_path/$script_name
fi;

if [ "`grep selected.2= $props_path/io.prop | awk -F= '{print $2;}'`" != "" ]
  then
    echo "     Internal I/O scheduler   = `grep selected.2= $props_path/io.prop | awk -F= '{print $2;}'`" >>$log_file
    cat $sub_scripts_path/io/2.`grep selected.2= $props_path/io.prop | awk -F= '{print $2;}'` >>$script_path/$script_name
fi;

#if [ "`grep selected.3= $props_path/io.prop | awk -F= '{print $2;}'`" != "" ]
#  then
#    echo "     Dynamic FSync            = `grep selected.3= $props_path/io.prop | awk -F= '{print $2;}'`" >>$log_file
#    cat $sub_scripts_path/io/3.`grep selected.3= $props_path/io.prop | awk -F= '{print $2;}'` >>$script_path/$script_name
#fi;

# Color configuration ----------------------------------------------------------------------------

echo "" >>$log_file
echo "Color configuration" >>$log_file

if [ "`grep selected.1= $props_path/color.prop | awk -F= '{print $2;}'`" != "" ]
  then
    echo "     Color settings = `grep selected.1= $props_path/color.prop | awk -F= '{print $2;}'`" >>$log_file
    cat $sub_scripts_path/color/1.`grep selected.1= $props_path/color.prop | awk -F= '{print $2;}'` >>$script_path/$script_name
fi;

# Virtual memory configuration -------------------------------------------------------------------

#echo "" >>$log_file
#echo "Virtual memory configuration" >>$log_file
#
#if [ "`grep selected.1= $props_path/swap.prop | awk -F= '{print $2;}'`" != "" ]
#  then
#    echo "     zSwap      = `grep selected.1= $props_path/swap.prop | awk -F= '{print $2;}'`" >>$log_file
#    cat $sub_scripts_path/swap/1.`grep selected.1= $props_path/swap.prop | awk -F= '{print $2;}'` >>$script_path/$script_name
#fi;
#
#if [ "`grep selected.2= $props_path/swap.prop | awk -F= '{print $2;}'`" != "" ]
#  then
#    echo "     Swappiness = `grep selected.2= $props_path/swap.prop | awk -F= '{print $2;}'`" >>$log_file
#    cat $sub_scripts_path/swap/2.`grep selected.2= $props_path/swap.prop | awk -F= '{print $2;}'` >>$script_path/$script_name
#fi;

# Finish adding the script footer ----------------------------------------------------------------

cat $sub_scripts_path/footer >>$script_path/$script_name

# Installing generated script to system init -----------------------------------------------------

echo "" >>$log_file
echo "Installing generated script to /system/etc" >>$log_file

rm /system/etc/$script_name
cp $script_path/$script_name /system/etc/$script_name
chmod 755 /system/etc/$script_name
chown 0:2000 /system/etc/$script_name

# Keep a backup of the prop files
rm -rf /data/yank555.lu-debug
mkdir /data/yank555.lu-debug
cp $props_path/*.prop /data/yank555.lu-debug

# All done for this step -------------------------------------------------------------------------